@@ -1,8 +1,9 @@
 import time
 from xml.etree.ElementTree import Element, SubElement
 from docmaptools import parse as docmap_parse
+from elifearticle.article import Affiliation, Contributor, Role
+from elifetools import xmlio
 from jatsgenerator import build as jats_build
-from elifetools.utils import doi_to_doi_uri
 from elifecleaner import LOGGER
 
 # for each ISSN, values for journal-id-type tag text
@@ -311,6 +312,28 @@ def volume_from_docmap(docmap_string, version_doi=None, identifier=None):
     return volume
 
 
+def article_id_from_docmap(docmap_string, version_doi=None, identifier=None):
+    "from the docmap get the article_id"
+    LOGGER.info("Parse docmap json")
+    d_json = docmap_parse.docmap_json(docmap_string)
+    if not d_json:
+        LOGGER.warning(
+            "%s parsing docmap returned None",
+            identifier,
+        )
+        return None
+    article_id = docmap_parse.preprint_identifier(
+        d_json, version_doi=version_doi, identifier=identifier
+    )
+    if not article_id:
+        LOGGER.warning(
+            "%s no article_id found in the docmap",
+            identifier,
+        )
+        return None
+    return article_id
+
+
 def license_from_docmap(docmap_string, version_doi=None, identifier=None):
     "from the docmap get the license"
     LOGGER.info("Parse docmap json")
@@ -399,66 +422,221 @@ def add_history_date(root, date_type, date_struct, identifier=None):
     return root
 
 
-EVENT_DESC_PREPRINT = "This manuscript was published as a preprint."
-EVENT_DESC_REVIEWED_PREPRINT = "This manuscript was published as a reviewed preprint."
-EVENT_DESC_REVISED_PREPRINT = "The reviewed preprint was revised."
+def set_article_id(xml_root, article_id, doi, version_doi):
+    "add article-id tags"
+    # add manuscript ID
+    if article_id:
+        article_meta_tag = xml_root.find(".//front/article-meta")
+        article_id_tag = Element("article-id")
+        article_id_tag.set("pub-id-type", "publisher-id")
+        article_id_tag.text = str(article_id)
+        article_meta_tag.insert(0, article_id_tag)
+    # add regular DOI tag
+    add_doi(xml_root, doi, specific_use=None, identifier=version_doi)
+    # add version DOI tag
+    add_version_doi(xml_root, version_doi, version_doi)
 
 
-def add_pub_history(root, history_data, identifier=None):
-    "add the pub-history tag and add event data to it"
-    if not history_data:
-        return root
-    article_meta_tag = root.find(".//front/article-meta")
-    if article_meta_tag is None:
-        LOGGER.warning(
-            "%s article-meta tag not found",
-            identifier,
-        )
-        return root
-    # look for an existing pub-history tag
-    pub_history_tag = article_meta_tag.find("./pub-history")
-    # if no pub-history tag, add one
-    if pub_history_tag is None:
-        # insert the new tag into the XML after the history or elocation-id tag
-        insert_index = 1
+def set_volume(root, volume):
+    "set volume tag text, add volume tag if not present"
+    # find volume tag
+    tag = root.find(".//front/article-meta/volume")
+    if tag is None:
+        article_meta_tag = root.find(".//front/article-meta")
+        if article_meta_tag is not None:
+            # add volume tag
+            tag_index = xmlio.get_first_element_index(article_meta_tag, "elocation-id")
+            if tag_index:
+                # insert volume tag in the right tag order
+                tag = Element("volume")
+                article_meta_tag.insert(tag_index - 1, tag)
+            else:
+                # append to the end of article-meta
+                tag = SubElement(article_meta_tag, "volume")
+    if tag is not None:
+        tag.text = str(volume)
+
+
+def set_elocation_id(root, elocation_id):
+    "set elocation-id tag text, add elocation-id tag if not present"
+    # find elocation-id tag
+    tag = root.find(".//front/article-meta/elocation-id")
+    if tag is None:
+        article_meta_tag = root.find(".//front/article-meta")
+        if article_meta_tag is not None:
+            # add elocation-id tag
+            tag_index = xmlio.get_first_element_index(article_meta_tag, "volume")
+            if tag_index:
+                # insert elocation-id tag in the right tag order
+                tag = Element("elocation-id")
+                article_meta_tag.insert(tag_index, tag)
+            else:
+                # append to the end of article-meta
+                tag = SubElement(article_meta_tag, "elocation-id")
+    if tag is not None:
+        tag.text = str(elocation_id)
+
+
+def set_article_categories(xml_root, display_channel=None, article_categories=None):
+    "add tags to article-categories tag"
+    article_meta_tag = xml_root.find(".//front/article-meta")
+    article_categories_tag = article_meta_tag.find(".//article-categories")
+    if article_categories_tag is None:
+        # insert the new tag into the XML after the article-id tags and before title-group
+        insert_index = None
         for tag_index, tag in enumerate(article_meta_tag.findall("*")):
-            if tag.tag in "history":
+            if tag.tag == "article-id":
+                insert_index = tag_index + 1
+            if tag.tag == "title-group":
+                break
+        article_categories_tag = Element("article-categories")
+        article_meta_tag.insert(insert_index, article_categories_tag)
+
+    if article_categories_tag is not None and display_channel:
+        jats_build.set_display_channel(article_categories_tag, display_channel)
+
+    if article_categories_tag is not None and article_categories:
+        for article_category in article_categories:
+            jats_build.set_major_subject_area(article_categories_tag, article_category)
+
+
+def set_license_tag(parent, license_data_dict):
+    "add license tag to parent tag"
+    if not license_data_dict.get("href"):
+        return
+    license_tag = SubElement(parent, "license")
+    license_tag.set(
+        "{http://www.w3.org/1999/xlink}href",
+        str(license_data_dict.get("href")),
+    )
+    ali_license_href_tag = SubElement(
+        license_tag, "{http://www.niso.org/schemas/ali/1.0/}license_ref"
+    )
+    ali_license_href_tag.text = license_data_dict.get("href")
+    # license-p tag
+    license_p_tag = SubElement(license_tag, "license-p")
+    license_p_tag.text = license_data_dict.get("paragraph1")
+    license_ext_link_tag = SubElement(license_p_tag, "ext-link")
+    license_ext_link_tag.set("ext-link-type", "uri")
+    license_ext_link_tag.set(
+        "{http://www.w3.org/1999/xlink}href",
+        license_data_dict.get("href"),
+    )
+    license_ext_link_tag.text = license_data_dict.get("name")
+    license_ext_link_tag.tail = license_data_dict.get("paragraph2")
+
+
+def set_permissions(xml_root, license_data_dict, copyright_year, copyright_holder):
+    "add license data to permissions tag"
+    article_meta_tag = xml_root.find(".//front/article-meta")
+    permissions_tag = article_meta_tag.find("./permissions")
+    if permissions_tag is None:
+        # insert the new tag into the XML after the pub-history or history tag
+        insert_index = None
+        for tag_index, tag in enumerate(article_meta_tag.findall("*")):
+            if tag.tag == "pub-history":
                 insert_index = tag_index + 1
                 break
-            if tag.tag == "elocation-id":
+            if tag.tag == "history":
                 insert_index = tag_index + 1
-        pub_history_tag = Element("pub-history")
-        article_meta_tag.insert(insert_index, pub_history_tag)
-    # add event tags to the pub-history tag
-    added_reviewed_preprint = None
-    for history_event_data in history_data:
-        event_tag = SubElement(pub_history_tag, "event")
-        if history_event_data.get("type"):
-            if history_event_data.get("type") == "preprint":
-                event_desc_tag = SubElement(event_tag, "event-desc")
-                event_desc_tag.text = EVENT_DESC_PREPRINT
-            elif history_event_data.get("type") == "reviewed-preprint":
-                event_desc_tag = SubElement(event_tag, "event-desc")
-                if added_reviewed_preprint:
-                    # already added one reviewed-preprint
-                    event_desc_tag.text = EVENT_DESC_REVISED_PREPRINT
-                else:
-                    # adding the first reviewed-preprint
-                    event_desc_tag.text = EVENT_DESC_REVIEWED_PREPRINT
-                added_reviewed_preprint = True
-        if history_event_data.get("date"):
-            date_struct = date_struct_from_string(history_event_data.get("date"))
-            date_tag = SubElement(event_tag, "date")
-            if history_event_data.get("type"):
-                date_tag.set("date-type", history_event_data.get("type"))
-            jats_build.set_dmy(date_tag, date_struct)
-            date_tag.set("iso-8601-date", time.strftime("%Y-%m-%d", date_struct))
-            if history_event_data.get("doi"):
-                self_uri_tag = SubElement(event_tag, "self-uri")
-                if history_event_data.get("type"):
-                    self_uri_tag.set("content-type", history_event_data.get("type"))
-                self_uri_tag.set(
-                    "{http://www.w3.org/1999/xlink}href",
-                    doi_to_doi_uri(history_event_data.get("doi")),
-                )
-    return root
+        permissions_tag = Element("permissions")
+        article_meta_tag.insert(insert_index, permissions_tag)
+    if license_data_dict:
+        if license_data_dict.get("copyright"):
+            jats_build.set_copyright_tags(
+                permissions_tag, copyright_year, copyright_holder
+            )
+        ali_free_to_read_tag = SubElement(
+            permissions_tag, "{http://www.niso.org/schemas/ali/1.0/}free_to_read"
+        )
+        set_license_tag(permissions_tag, license_data_dict)
+
+
+CONTRIB_TYPE_ROLE_MAP = {"editor": "Reviewing Editor", "senior_editor": "Senior Editor"}
+
+
+def editor_contributors(docmap_string, version_doi):
+    "populate Contributor objects with editor data from a docmap"
+    editors = []
+
+    data = docmap_parse.docmap_editor_data(docmap_string, version_doi)
+
+    for data_item in data:
+        contrib_type = data_item.get("role", "").replace("-", "_")
+        roles = []
+        aff = None
+        if contrib_type:
+            editor_role = Role()
+            editor_role.text = CONTRIB_TYPE_ROLE_MAP.get(contrib_type)
+            roles.append(editor_role)
+        if data_item.get("actor"):
+            surname = data_item.get("actor").get("surname")
+            given_name = " ".join(
+                [
+                    name_part
+                    for name_part in [
+                        data_item.get("actor").get("firstName"),
+                        data_item.get("actor").get("_middleName"),
+                    ]
+                    if name_part
+                ]
+            )
+            # format affiliation
+            affiliation_data_dict = data_item.get("actor").get("affiliation")
+            if affiliation_data_dict:
+                aff = Affiliation()
+                if (
+                    affiliation_data_dict.get("name")
+                    and affiliation_data_dict.get("type") == "organization"
+                ):
+                    aff.institution = (
+                        data_item.get("actor").get("affiliation").get("name")
+                    )
+                if affiliation_data_dict.get("location"):
+                    # parse and set city and country values
+                    location_parts = affiliation_data_dict.get("location").split(",")
+                    if len(location_parts) == 2:
+                        aff.city = location_parts[0]
+                        aff.country = location_parts[1].lstrip()
+
+        editor = Contributor(contrib_type, surname, given_name)
+        editor.roles = roles
+        if aff:
+            editor.set_affiliation(aff)
+        editors.append(editor)
+
+    return editors
+
+
+def set_editors(parent, editors):
+    "set editor contrib tags"
+    if not editors:
+        return
+    # find where to insert a contrib-group tag
+    insert_index = None
+    for tag_index, tag in enumerate(parent.findall("*")):
+        if tag.tag == "contrib-group":
+            insert_index = tag_index + 1
+    # insert contrib-group tag
+    contrib_group_tag = Element("contrib-group")
+    if insert_index:
+        parent.insert(insert_index, contrib_group_tag)
+    else:
+        parent.append(contrib_group_tag)
+    contrib_group_tag.set("content-type", "section")
+    for editor in editors:
+        contrib_tag = SubElement(contrib_group_tag, "contrib")
+        contrib_tag.set("contrib-type", editor.contrib_type)
+        jats_build.set_contrib_name(contrib_tag, editor)
+        jats_build.set_contrib_orcid(contrib_tag, editor)
+        # role tag
+        jats_build.set_contrib_role(contrib_tag, editor.contrib_type, editor)
+        # add inline aff tags
+        for affiliation in editor.affiliations:
+            jats_build.set_aff(
+                contrib_tag,
+                affiliation,
+                editor.contrib_type,
+                tail="",
+                institution_wrap=True,
+            )
