@@ -3,9 +3,11 @@ import time
 import unittest
 from xml.etree import ElementTree
 import json
+from elifearticle.article import Affiliation, Contributor, Role
 from elifetools import xmlio
 from elifecleaner import LOGGER, configure_logging, prc
-from tests.helpers import delete_files_in_folder
+from tests.helpers import delete_files_in_folder, read_fixture
+
 
 # elife ISSN example of non-PRC journal-id tag values
 NON_PRC_XML = (
@@ -84,7 +86,6 @@ class TestTransformJournalIdTags(unittest.TestCase):
         # populate an ElementTree
         identifier = "test.zip"
         xml_string = PRC_XML
-        expected = bytes(NON_PRC_XML, encoding="utf-8")
         root = ElementTree.fromstring(xml_string)
         # invoke the function
         root_output = prc.transform_journal_id_tags(root, identifier)
@@ -734,6 +735,81 @@ class TestReviewDateFromDocmap(unittest.TestCase):
             )
 
 
+class TestArticleIdFromDocmap(unittest.TestCase):
+    "tests for article_id_from_docmap()"
+
+    def setUp(self):
+        self.temp_dir = "tests/tmp"
+        self.log_file = os.path.join(self.temp_dir, "test.log")
+        self.log_handler = configure_logging(self.log_file)
+        self.identifier = "test.zip"
+
+    def tearDown(self):
+        LOGGER.removeHandler(self.log_handler)
+        delete_files_in_folder(self.temp_dir, filter_out=[".keepme"])
+
+    def test_article_id_from_docmap(self):
+        "parse article_id from docmap preprint output"
+        docmap_json = docmap_test_data()
+        expected = "85111"
+        # invoke
+        result = prc.article_id_from_docmap(
+            json.dumps(docmap_json), identifier=self.identifier
+        )
+        # assert
+        self.assertEqual(result, expected)
+        with open(self.log_file, "r") as open_file:
+            log_messages = open_file.readlines()
+        self.assertEqual(
+            log_messages[0],
+            ("INFO elifecleaner:prc:article_id_from_docmap: " "Parse docmap json\n"),
+        )
+
+    def test_no_article_id(self):
+        "test if no article_id data can be found in the docmap"
+        docmap_json = docmap_test_data()
+        del docmap_json["steps"]["_:b1"]["actions"][0]["outputs"][0]["identifier"]
+        expected = None
+        # invoke
+        result = prc.article_id_from_docmap(
+            json.dumps(docmap_json), identifier=self.identifier
+        )
+        with open(self.log_file, "r") as open_file:
+            log_messages = open_file.readlines()
+        # assert
+        self.assertEqual(result, expected)
+        with open(self.log_file, "r") as open_file:
+            log_messages = open_file.readlines()
+            self.assertEqual(
+                log_messages[-1],
+                (
+                    "WARNING elifecleaner:prc:article_id_from_docmap: "
+                    "%s no article_id found in the docmap\n"
+                )
+                % self.identifier,
+            )
+
+    def test_docmap_is_none(self):
+        "test if docmap is empty"
+        docmap_json = {}
+        # invoke
+        result = prc.article_id_from_docmap(
+            json.dumps(docmap_json), identifier=self.identifier
+        )
+        # assert
+        self.assertEqual(result, None)
+        with open(self.log_file, "r") as open_file:
+            log_messages = open_file.readlines()
+            self.assertEqual(
+                log_messages[-1],
+                (
+                    "WARNING elifecleaner:prc:article_id_from_docmap: "
+                    "%s parsing docmap returned None\n"
+                )
+                % self.identifier,
+            )
+
+
 class TestLicenseFromDocmap(unittest.TestCase):
     "tests for license_from_docmap()"
 
@@ -1133,129 +1209,466 @@ class TestAddHistoryDate(unittest.TestCase):
         self.assertEqual(ElementTree.tostring(root_output), expected)
 
 
-class TestAddPubHistory(unittest.TestCase):
-    "tests for prc.add_pub_history()"
+class TestSetArticleId(unittest.TestCase):
+    "tests for set_article_id()"
+
+    def test_set_article_id(self):
+        "test adding various article-id tags"
+        xml_string = "<article><front><article-meta /></front></article>"
+        xml_root = ElementTree.fromstring(xml_string)
+        article_id = "95901"
+        doi = "10.7554/eLife.95901"
+        version_doi = "10.7554/eLife.95901.1"
+        expected = (
+            "<article>"
+            "<front>"
+            "<article-meta>"
+            '<article-id pub-id-type="publisher-id">%s</article-id>'
+            '<article-id pub-id-type="doi">%s</article-id>'
+            '<article-id pub-id-type="doi" specific-use="version">%s</article-id>'
+            "</article-meta>"
+            "</front>"
+            "</article>" % (article_id, doi, version_doi)
+        )
+        # invoke
+        prc.set_article_id(xml_root, article_id, doi, version_doi)
+        # assert
+        self.assertEqual(ElementTree.tostring(xml_root).decode("utf-8"), expected)
+
+
+class TestSetVolume(unittest.TestCase):
+    "tests for set_volume()"
+
+    def test_modify(self):
+        "test modifying existing volume tag"
+        xml_string = (
+            "<article><front><article-meta>"
+            "<volume>foo</volume>"
+            "</article-meta></front></article>"
+        )
+        root = ElementTree.fromstring(xml_string)
+        volume = "12"
+        expected = (
+            "<article><front><article-meta>"
+            "<volume>12</volume>"
+            "</article-meta></front></article>"
+        )
+        prc.set_volume(root, volume)
+        self.assertEqual(ElementTree.tostring(root).decode("utf8"), expected)
+
+    def test_insert_before(self):
+        "test inserting volume tag before elocation-id tag"
+        xml_string = (
+            "<article><front><article-meta>"
+            "<elocation-id />"
+            "</article-meta></front></article>"
+        )
+        root = ElementTree.fromstring(xml_string)
+        volume = "12"
+        expected = (
+            "<article><front><article-meta>"
+            "<volume>12</volume>"
+            "<elocation-id />"
+            "</article-meta></front></article>"
+        )
+        prc.set_volume(root, volume)
+        self.assertEqual(ElementTree.tostring(root).decode("utf8"), expected)
+
+    def test_append(self):
+        "test appending volume tag if no elocation-id tag"
+        xml_string = "<article><front><article-meta /></front></article>"
+        root = ElementTree.fromstring(xml_string)
+        volume = "12"
+        expected = (
+            "<article><front><article-meta>"
+            "<volume>12</volume>"
+            "</article-meta></front></article>"
+        )
+        prc.set_volume(root, volume)
+        self.assertEqual(ElementTree.tostring(root).decode("utf8"), expected)
+
+
+class TestSetElocationId(unittest.TestCase):
+    "tests for set_elocation_id()"
+
+    def test_set_elocation_id(self):
+        "test modifying existing elocation-id tag"
+        xml_string = (
+            "<article><front><article-meta>"
+            "<elocation-id>foo</elocation-id>"
+            "</article-meta></front></article>"
+        )
+        root = ElementTree.fromstring(xml_string)
+        elocation_id = "RP95901"
+        expected = (
+            "<article><front><article-meta>"
+            "<elocation-id>RP95901</elocation-id>"
+            "</article-meta></front></article>"
+        )
+        prc.set_elocation_id(root, elocation_id)
+        self.assertEqual(ElementTree.tostring(root).decode("utf8"), expected)
+
+    def test_insert_after(self):
+        "test inserting elocation-id tag after volume tag"
+        xml_string = (
+            "<article><front><article-meta>"
+            "<volume />"
+            "</article-meta></front></article>"
+        )
+        root = ElementTree.fromstring(xml_string)
+        elocation_id = "RP95901"
+        expected = (
+            "<article><front><article-meta>"
+            "<volume />"
+            "<elocation-id>RP95901</elocation-id>"
+            "</article-meta></front></article>"
+        )
+        prc.set_elocation_id(root, elocation_id)
+        self.assertEqual(ElementTree.tostring(root).decode("utf8"), expected)
+
+    def test_append(self):
+        "test appending volume tag if no elocation-id tag"
+        xml_string = "<article><front><article-meta /></front></article>"
+        root = ElementTree.fromstring(xml_string)
+        elocation_id = "RP95901"
+        expected = (
+            "<article><front><article-meta>"
+            "<elocation-id>RP95901</elocation-id>"
+            "</article-meta></front></article>"
+        )
+        prc.set_elocation_id(root, elocation_id)
+        self.assertEqual(ElementTree.tostring(root).decode("utf8"), expected)
+
+
+class TestSetArticleCategories(unittest.TestCase):
+    "tests for set_article_categories()"
+
+    def test_set_article_categories(self):
+        "test adding subject tags to article-categories"
+        xml_root = ElementTree.fromstring(
+            "<article>"
+            "<front>"
+            "<article-meta>"
+            "<article-categories />"
+            "</article-meta>"
+            "</front>"
+            "</article>"
+        )
+        display_channel = "Research Article"
+        article_categories = ["Structural Biology and Molecular Biophysics"]
+        expected = (
+            "<article>"
+            "<front>"
+            "<article-meta>"
+            "<article-categories>"
+            '<subj-group subj-group-type="display-channel">'
+            "<subject>Research Article</subject>"
+            "</subj-group>"
+            '<subj-group subj-group-type="heading">'
+            "<subject>Structural Biology and Molecular Biophysics</subject>"
+            "</subj-group>"
+            "</article-categories>"
+            "</article-meta>"
+            "</front>"
+            "</article>"
+        )
+        # invoke
+        prc.set_article_categories(xml_root, display_channel, article_categories)
+        # assert
+        xml_string = ElementTree.tostring(xml_root).decode("utf-8")
+        self.assertEqual(xml_string, expected)
+
+    def test_no_article_categories_tag(self):
+        "test inserting article-categories tag"
+        xml_root = ElementTree.fromstring(
+            "<article>"
+            "<front>"
+            "<article-meta>"
+            "<article-id />"
+            "<title-group />"
+            "</article-meta>"
+            "</front>"
+            "</article>"
+        )
+        display_channel = "Research Article"
+        article_categories = ["Structural Biology and Molecular Biophysics"]
+        expected = (
+            "<article>"
+            "<front>"
+            "<article-meta>"
+            "<article-id />"
+            "<article-categories>"
+            '<subj-group subj-group-type="display-channel">'
+            "<subject>Research Article</subject>"
+            "</subj-group>"
+            '<subj-group subj-group-type="heading">'
+            "<subject>Structural Biology and Molecular Biophysics</subject>"
+            "</subj-group>"
+            "</article-categories>"
+            "<title-group />"
+            "</article-meta>"
+            "</front>"
+            "</article>"
+        )
+        # invoke
+        prc.set_article_categories(xml_root, display_channel, article_categories)
+        # assert
+        xml_string = ElementTree.tostring(xml_root).decode("utf-8")
+        self.assertEqual(xml_string, expected)
+
+
+# cc-by license data
+LICENSE_DATA_DICT_CC_BY = {
+    "license_id": 1,
+    "license_type": "open-access",
+    "copyright": True,
+    "href": "http://creativecommons.org/licenses/by/4.0/",
+    "name": "Creative Commons Attribution License",
+    "paragraph1": "This article is distributed under the terms of the ",
+    "paragraph2": (
+        ", which permits unrestricted use and redistribution provided that the"
+        " original author and source are credited."
+    ),
+}
+
+# cc-0 license data
+LICENSE_DATA_DICT_CC_0 = {
+    "license_id": 2,
+    "license_type": "open-access",
+    "copyright": False,
+    "href": "http://creativecommons.org/publicdomain/zero/1.0/",
+    "name": "Creative Commons CC0 public domain dedication",
+    "paragraph1": (
+        "This is an open-access article, free of all copyright, and may be"
+        " freely reproduced, distributed, transmitted, modified, built upon, or"
+        " otherwise used by anyone for any lawful purpose. The work is made"
+        " available under the "
+    ),
+    "paragraph2": ".",
+}
+
+
+class TestLicenseTag(unittest.TestCase):
+    "tests for license_tag()"
 
     def setUp(self):
         # register XML namespaces
         xmlio.register_xmlns()
 
-        self.xml_string_template = '<article xmlns:xlink="http://www.w3.org/1999/xlink"><front><article-meta>%s</article-meta></front></article>'
-        self.history_data = [
-            {
-                "type": "preprint",
-                "date": "2022-11-22",
-                "doi": "10.1101/2022.11.08.515698",
-                "url": "https://www.biorxiv.org/content/10.1101/2022.11.08.515698v2",
-                "versionIdentifier": "2",
-                "published": "2022-11-22",
-                "content": [
-                    {
-                        "type": "computer-file",
-                        "url": "s3://transfers-elife/biorxiv_Current_Content/November_2022/23_Nov_22_Batch_1444/b0f4d90b-6c92-1014-9a2e-aae015926ab4.meca",
-                    }
-                ],
-            },
-            {
-                "type": "reviewed-preprint",
-                "date": "2023-01-25T14:00:00+00:00",
-                "identifier": "85111",
-                "doi": "10.7554/eLife.85111.1",
-                "versionIdentifier": "1",
-                "license": "http://creativecommons.org/licenses/by/4.0/",
-                "published": "2023-01-25T14:00:00+00:00",
-            },
-            {
-                "type": "reviewed-preprint",
-                "date": "2023-05-10T14:00:00+00:00",
-                "identifier": "85111",
-                "doi": "10.7554/eLife.85111.2",
-                "versionIdentifier": "2",
-                "license": "http://creativecommons.org/licenses/by/4.0/",
-                "published": "2023-05-10T14:00:00+00:00",
-            },
-        ]
-        self.identifier = "test.zip"
-        # expected history XML string for when using the input values
-        self.xml_output = (
-            "<pub-history>"
-            "<event>"
-            "<event-desc>This manuscript was published as a preprint.</event-desc>"
-            '<date date-type="preprint" iso-8601-date="2022-11-22">'
-            "<day>22</day>"
-            "<month>11</month>"
-            "<year>2022</year>"
-            "</date>"
-            '<self-uri content-type="preprint" xlink:href="https://doi.org/10.1101/2022.11.08.515698" />'
-            "</event>"
-            "<event>"
-            "<event-desc>This manuscript was published as a reviewed preprint.</event-desc>"
-            '<date date-type="reviewed-preprint" iso-8601-date="2023-01-25">'
-            "<day>25</day>"
-            "<month>01</month>"
-            "<year>2023</year>"
-            "</date>"
-            '<self-uri content-type="reviewed-preprint" xlink:href="https://doi.org/10.7554/eLife.85111.1" />'
-            "</event>"
-            "<event>"
-            "<event-desc>The reviewed preprint was revised.</event-desc>"
-            '<date date-type="reviewed-preprint" iso-8601-date="2023-05-10">'
-            "<day>10</day>"
-            "<month>05</month>"
-            "<year>2023</year>"
-            "</date>"
-            '<self-uri content-type="reviewed-preprint" xlink:href="https://doi.org/10.7554/eLife.85111.2" />'
-            "</event>"
-            "</pub-history>"
+    def test_cc_by(self):
+        "test setting CC-BY license tag"
+        parent = ElementTree.fromstring("<permissions />")
+        expected = (
+            '<permissions xmlns:ali="http://www.niso.org/schemas/ali/1.0/"'
+            ' xmlns:xlink="http://www.w3.org/1999/xlink">'
+            '<license xlink:href="http://creativecommons.org/licenses/by/4.0/">'
+            "<ali:license_ref>"
+            "http://creativecommons.org/licenses/by/4.0/"
+            "</ali:license_ref>"
+            "<license-p>"
+            "This article is distributed under the terms of the"
+            ' <ext-link ext-link-type="uri"'
+            ' xlink:href="http://creativecommons.org/licenses/by/4.0/">'
+            "Creative Commons Attribution License"
+            "</ext-link>"
+            ", which permits unrestricted use and redistribution provided that the"
+            " original author and source are credited."
+            "</license-p>"
+            "</license>"
+            "</permissions>"
         )
+        # invoke
+        prc.set_license_tag(parent, LICENSE_DATA_DICT_CC_BY)
+        # assert
+        xml_string = ElementTree.tostring(parent).decode("utf-8")
+        self.assertEqual(xml_string, expected)
 
-    def test_add_pub_history(self):
-        "test adding to an existing pub-history tag"
-        xml_string = self.xml_string_template % "<pub-history />"
-        expected = bytes(self.xml_string_template % self.xml_output, encoding="utf-8")
-        root = ElementTree.fromstring(xml_string)
-        root_output = prc.add_pub_history(root, self.history_data, self.identifier)
-        print(ElementTree.tostring(root_output))
-        self.assertEqual(ElementTree.tostring(root_output), expected)
+    def test_cc_0(self):
+        "test setting CC-0 license tag"
+        parent = ElementTree.fromstring("<permissions />")
+        expected = (
+            '<permissions xmlns:ali="http://www.niso.org/schemas/ali/1.0/"'
+            ' xmlns:xlink="http://www.w3.org/1999/xlink">'
+            '<license xlink:href="http://creativecommons.org/publicdomain/zero/1.0/">'
+            "<ali:license_ref>"
+            "http://creativecommons.org/publicdomain/zero/1.0/"
+            "</ali:license_ref>"
+            "<license-p>"
+            "This is an open-access article, free of all copyright, and may be freely"
+            " reproduced, distributed, transmitted, modified, built upon, or otherwise"
+            " used by anyone for any lawful purpose. The work is made available under the"
+            ' <ext-link ext-link-type="uri"'
+            ' xlink:href="http://creativecommons.org/publicdomain/zero/1.0/">'
+            "Creative Commons CC0 public domain dedication"
+            "</ext-link>."
+            "</license-p>"
+            "</license>"
+            "</permissions>"
+        )
+        # invoke
+        prc.set_license_tag(parent, LICENSE_DATA_DICT_CC_0)
+        # assert
+        xml_string = ElementTree.tostring(parent).decode("utf-8")
+        self.assertEqual(xml_string, expected)
 
     def test_no_data(self):
-        "test for if there is no data to be added"
-        # use xlink:href in the sample and the xmlns is kept in the output
-        xml_string = (
-            self.xml_string_template % '<ext-link xlink:href="https://example.org" />'
-        )
-        history_data = None
-        expected = bytes(xml_string, encoding="utf-8")
-        root = ElementTree.fromstring(xml_string)
-        root_output = prc.add_pub_history(root, history_data, self.identifier)
-        self.assertEqual(ElementTree.tostring(root_output), expected)
+        "test if no data is provided"
+        parent = ElementTree.fromstring("<permissions />")
+        license_data_dict = {}
+        expected = "<permissions />"
+        # invoke
+        prc.set_license_tag(parent, license_data_dict)
+        # assert
+        xml_string = ElementTree.tostring(parent).decode("utf-8")
+        self.assertEqual(xml_string, expected)
 
-    def test_after_history_tag(self):
-        "test adding a pub-history tag after an existing history tag"
-        xml_string = self.xml_string_template % "<history />"
-        expected = bytes(
-            self.xml_string_template % ("<history />" + self.xml_output),
-            encoding="utf-8",
-        )
-        root = ElementTree.fromstring(xml_string)
-        root_output = prc.add_pub_history(root, self.history_data, self.identifier)
-        self.assertEqual(ElementTree.tostring(root_output), expected)
 
-    def test_elocation_id_tag(self):
-        "test pub-history tag should be added after the elocation-id tag"
-        xml_string = self.xml_string_template % "<elocation-id />"
-        expected = bytes(
-            self.xml_string_template % ("<elocation-id />" + self.xml_output),
-            encoding="utf-8",
-        )
-        root = ElementTree.fromstring(xml_string)
-        root_output = prc.add_pub_history(root, self.history_data, self.identifier)
-        self.assertEqual(ElementTree.tostring(root_output), expected)
+class TestSetPermissions(unittest.TestCase):
+    "tests for set_permissions()"
 
-    def test_no_article_meta(self):
-        "test if there is no article-meta tag"
-        xml_string = "<article />"
-        expected = b"<article />"
-        root = ElementTree.fromstring(xml_string)
-        root_output = prc.add_pub_history(root, self.history_data, self.identifier)
-        self.assertEqual(ElementTree.tostring(root_output), expected)
+    def test_set_permissions(self):
+        "test setting permissions and license XML"
+        xml_root = ElementTree.fromstring(
+            "<article>"
+            "<front>"
+            "<article-meta>"
+            "<history />"
+            "<pub-history />"
+            "</article-meta>"
+            "</front>"
+            "</article>"
+        )
+        copyright_year = "2024"
+        copyright_holder = "Surname et al"
+        expected = (
+            '<article xmlns:ali="http://www.niso.org/schemas/ali/1.0/"'
+            ' xmlns:xlink="http://www.w3.org/1999/xlink">'
+            "<front>"
+            "<article-meta>"
+            "<history />"
+            "<pub-history />"
+            "<permissions>"
+            "<copyright-statement>© 2024, Surname et al</copyright-statement>"
+            "<copyright-year>2024</copyright-year>"
+            "<copyright-holder>Surname et al</copyright-holder>"
+            "<ali:free_to_read />"
+            '<license xlink:href="http://creativecommons.org/licenses/by/4.0/">'
+            "<ali:license_ref>http://creativecommons.org/licenses/by/4.0/</ali:license_ref>"
+            "<license-p>This article is distributed under the terms of the"
+            ' <ext-link ext-link-type="uri"'
+            ' xlink:href="http://creativecommons.org/licenses/by/4.0/">'
+            "Creative Commons Attribution License"
+            "</ext-link>, which permits unrestricted use and redistribution provided that"
+            " the original author and source are credited."
+            "</license-p>"
+            "</license>"
+            "</permissions>"
+            "</article-meta>"
+            "</front>"
+            "</article>"
+        )
+        # invoke
+        prc.set_permissions(
+            xml_root, LICENSE_DATA_DICT_CC_BY, copyright_year, copyright_holder
+        )
+        # assert
+        xml_string = ElementTree.tostring(xml_root, encoding="utf-8").decode("utf-8")
+        self.assertEqual(xml_string, expected)
+
+
+class TestEditorContributors(unittest.TestCase):
+    "tests for editor_contributors()"
+
+    def test_editor_contributors(self):
+        "test populating editor Contributor objects"
+        docmap_string = read_fixture("99854.json", mode="r")
+        version_doi = "10.7554/eLife.99854.1"
+        # invoke
+        editors = prc.editor_contributors(docmap_string, version_doi)
+        # assert
+        self.assertEqual(len(editors), 2)
+        self.assertEqual(editors[0].surname, "Proenza")
+        self.assertEqual(editors[0].contrib_type, "editor")
+        self.assertEqual(
+            str(editors[0].affiliations[0]),
+            (
+                "{'institution': 'University of Colorado Anschutz Medical Campus',"
+                " 'city': 'Aurora', 'country': 'United States of America'}"
+            ),
+        )
+        self.assertEqual(editors[1].surname, "Swartz")
+        self.assertEqual(editors[1].contrib_type, "senior_editor")
+        self.assertEqual(
+            str(editors[1].affiliations[0]),
+            (
+                "{'institution': 'National Institute of Neurological Disorders and Stroke',"
+                " 'city': 'Bethesda', 'country': 'United States of America'}"
+            ),
+        )
+
+
+class TestSetEditors(unittest.TestCase):
+    "tests for set_editors()"
+
+    def setUp(self):
+        self.editor = Contributor(
+            contrib_type="editor", surname="Surname", given_name="Given"
+        )
+        editor_role = Role()
+        editor_role.text = "Reviewing Editor"
+        self.editor.roles = [editor_role]
+        aff = Affiliation()
+        aff.city = "City"
+        aff.country = "Country"
+        self.editor.set_affiliation(aff)
+
+    def test_set_editors(self):
+        "test setting editor contrib tags"
+        parent = ElementTree.fromstring("<root><contrib-group /></root>")
+        editors = [self.editor]
+        expected = (
+            "<root>"
+            "<contrib-group />"
+            '<contrib-group content-type="section">'
+            '<contrib contrib-type="editor">'
+            "<name>"
+            "<surname>Surname</surname>"
+            "<given-names>Given</given-names>"
+            "</name>"
+            "<role>Reviewing Editor</role>"
+            "<aff>"
+            "<addr-line>"
+            '<named-content content-type="city">City</named-content>'
+            "</addr-line>"
+            "<country>Country</country>"
+            "</aff>"
+            "</contrib>"
+            "</contrib-group>"
+            "</root>"
+        )
+        # invoke
+        prc.set_editors(parent, editors)
+        # assert
+        xml_string = ElementTree.tostring(parent).decode("utf-8")
+        self.assertEqual(xml_string, expected)
+
+    def test_append(self):
+        "test appending tag when insert order is not determined"
+        parent = ElementTree.fromstring("<root></root>")
+        editors = [self.editor]
+        # invoke
+        prc.set_editors(parent, editors)
+        # assert
+        xml_string = ElementTree.tostring(parent).decode("utf-8")
+        self.assertTrue('<contrib-group content-type="section">' in xml_string)
+
+    def test_no_editors(self):
+        "test if there is no editor data"
+        parent = ElementTree.fromstring("<root />")
+        editors = []
+        expected = "<root />"
+        # invoke
+        prc.set_editors(parent, editors)
+        # assert
+        xml_string = ElementTree.tostring(parent).decode("utf-8")
+        self.assertEqual(xml_string, expected)
